@@ -1116,12 +1116,14 @@ bool WaveClip::Paste(double t0, const WaveClip& o)
 
    if (GetSequenceSamplesCount() == 0)
    {
-      // Empty clip: we're flexible and adopt the other's stretching.
-      mRawAudioTempo = other.mRawAudioTempo;
+      // Empty clip: we're flexible and adopt the other's pitch and stretch.
+      mPitchAndSpeedPreset = other.mPitchAndSpeedPreset;
+      mCentShift = other.mCentShift;
       mClipStretchRatio = other.mClipStretchRatio;
+      mRawAudioTempo = other.mRawAudioTempo;
       mProjectTempo = other.mProjectTempo;
    }
-   else if (GetStretchRatio() != other.GetStretchRatio())
+   else if (!HasEqualPitchAndSpeed(other))
       // post is satisfied
       return false;
 
@@ -1145,7 +1147,7 @@ bool WaveClip::Paste(double t0, const WaveClip& o)
    if (t0 == GetPlayStartTime())
    {
       pastePositionShift = t0;
-      startPositionShift = other.GetSequenceStartTime() + GetTrimLeft();
+      startPositionShift = GetTrimLeft() - other.GetTrimLeft();
 
       finisher = ClearSequence(GetSequenceStartTime(), t0);
       SetTrimLeft(other.GetTrimLeft());
