@@ -437,6 +437,23 @@ void PopulatePreferences()
          gPrefs->DeleteEntry("/GUI/ShowSplashScreen");
    }
 
+   if (std::tuple { vMajor, vMinor, vMicro } < std::tuple{ 3, 7, 2 })
+   {
+      if (gPrefs->Exists("/GUI/ShowSplashScreen"))
+         gPrefs->DeleteEntry("/GUI/ShowSplashScreen");
+      // Reset Share Audio width
+      if(gPrefs->Exists("/GUI/ToolBars/Share Audio/W"))
+         gPrefs->DeleteEntry("/GUI/ToolBars/Share Audio/W");
+      // Show update and privacy policy dialog
+      if (gPrefs->Exists("/Update/UpdateNoticeShown"))
+         gPrefs->DeleteEntry("/Update/UpdateNoticeShown");
+      if (gPrefs->Exists("/Update/DefaultUpdatesChecking"))
+         gPrefs->DeleteEntry("/Update/DefaultUpdatesChecking");
+      // To set the new default to Best Quality
+      if (gPrefs->Exists("/Quality/LibsoxrSampleRateConverterChoice"))
+         gPrefs->DeleteEntry("/Quality/LibsoxrSampleRateConverterChoice");
+   }
+
    // write out the version numbers to the prefs file for future checking
    gPrefs->Write(wxT("/Version/Major"), AUDACITY_VERSION);
    gPrefs->Write(wxT("/Version/Minor"), AUDACITY_RELEASE);
@@ -1275,7 +1292,7 @@ AudacityApp::~AudacityApp()
 }
 
 void AudacityApp::ShowSplashScreen() {
-   // Bug 718: Position splash screen on same screen 
+   // Bug 718: Position splash screen on same screen
    // as where Audacity project will appear.
    wxRect wndRect;
    bool bMaximized = false;
@@ -1285,8 +1302,11 @@ void AudacityApp::ShowSplashScreen() {
    // BG: Create a temporary window to set as the top window
    wxImage logoimage((const char**)Audacity_splash_xpm);
    logoimage.Scale(logoimage.GetWidth() * (2.0 / 3.0), logoimage.GetHeight() * (2.0 / 3.0), wxIMAGE_QUALITY_HIGH);
+#ifdef __WXMSW__
+   // We need to mirror the image for right-to-left languages on Windows only
    if (GetLayoutDirection() == wxLayout_RightToLeft)
       logoimage = logoimage.Mirror();
+#endif
    wxBitmap logo(logoimage);
 
    mSplashScreen = std::make_unique<wxSplashScreen>(
@@ -1307,11 +1327,11 @@ void AudacityApp::ShowSplashScreen() {
       }
    );
 
-   // Unfortunately with the Windows 10 Creators update, the splash screen 
+   // Unfortunately with the Windows 10 Creators update, the splash screen
    // now appears before setting its position.
-   // On a dual monitor screen it will appear on one screen and then 
+   // On a dual monitor screen it will appear on one screen and then
    // possibly jump to the second.
-   // We could fix this by writing our own splash screen and using Hide() 
+   // We could fix this by writing our own splash screen and using Hide()
    // until the splash scren was correctly positioned, then Show()
 
    // Possibly move it on to the second screen...
@@ -1678,6 +1698,14 @@ bool AudacityApp::InitPart2()
       project = ProjectManager::New();
    }
 
+   // Update Manager may spawn a modal dialog, we need to hide the splash screen before that
+   bool splashFadeOut = !playingJournal;
+   HideSplashScreen(splashFadeOut);
+
+#if defined(HAVE_UPDATES_CHECK)
+   UpdateManager::Start(playingJournal);
+#endif
+
    if (!playingJournal && ProjectSettings::Get(*project).GetShowSplashScreen())
    {
       // This may do a check-for-updates at every start up.
@@ -1689,14 +1717,6 @@ bool AudacityApp::InitPart2()
 #endif
    }
 
-   // Update Manager may spawn a modal dialog, we need to hide the splash screen before that
-   bool splashFadeOut = !playingJournal;
-   HideSplashScreen(splashFadeOut);
-
-#if defined(HAVE_UPDATES_CHECK)
-   UpdateManager::Start(playingJournal);
-#endif
-
    Importer::Get().Initialize();
    ExportPluginRegistry::Get().Initialize();
 
